@@ -6,13 +6,12 @@
 
 import cmath
 import math
-from scipy import interpolate
-import matplotlib.pyplot as plt
+# import matplotlib.pyplot as plt
 import numpy as np
 import sys
 # sys.path.insert(0, ".")
-import xt, excel
-# from xt import engfmt, openplot
+from melib.xt import mdxziplist,engfmt,openplot
+from melib.excel import Xcel
 
 PIE = math.pi
 CALCRECORD = ""
@@ -156,9 +155,9 @@ def opendatafiles(tags=["bearing", "mats", "sgear", "shaft", "vbelt"], makezip=F
     for s in tags:
         #        datafilename=DATAFOLDER+"\\"+"%s.xlsx"%s
         datafilename=pt+"\\data\\%s.xlsx"%s
-        x.append(excel.Xcel(datafilename))
+        x.append(Xcel(datafilename))
         if makezip:
-            xt.mdxziplist([datafilename])
+            mdxziplist([datafilename])
     return x
 
 def alloyprop(x, base, alloyname, props):
@@ -214,7 +213,7 @@ def steelprop(x, alloyname, props):
     """ Short cut for `alloyprop(x, "STEELS", alloyname, props)`
 
     """
-    return alloyprop(x, "STEELS", alloyname, props)
+    return alloyprop(x, "steel", alloyname, props)
 
 # COLUMNS
 
@@ -1122,23 +1121,6 @@ def agmazn(Nc, surface=""):  # Nc:Nof cycles; surface:surface hardening
         return 1.4488/Nc**0.023
 
 
-# def plotIJ():
-#     N1 = np.arange(17, 30)
-#     N2 = np.array([17, 18, 25, 35, 50, 85, 170])
-#     N2 = np.array([17, 18])
-#     ax = plt.gca()
-#     ax.cla()  # clear things for fresh plot
-#     for n2 in N2:
-#         y = np.zeros(len(N1))
-#         x = np.zeros(len(N1))
-#         for k in range(0, len(N1)):
-#             x[k] = N1[k]
-#             y[k] = J2(x[k], n2)[0]
-#             print("%d: J(%.0f, %.0f)=%.3f" % (k, x[k], n2, y[k]))
-#         plt.plot(x, y, 'b-', linewidth=1)
-#     plt.show()
-#
-
 
 
 #
@@ -1151,7 +1133,7 @@ def shaftendur(uts, condition="ground"):
         the surface condition.  The returned value is the endurance strength
         read off the following chart:
 
-        .. image:: ../../pics/shaftendur.png
+        .. image:: ../../assets/shaftendur.png
 
         The valid options for the second argument are:
 
@@ -1253,7 +1235,7 @@ def shoulderscf(D, d, R, uts, record=False):  # as per AS1403
         Calculates the stress concentration factor for a shaft shoulder according to
         AS1403.
 
-            .. image:: ../../pics/shoulderscf.png
+            .. image:: ../../assets/shoulderscf.png
 
 
         ``D, d, R`` are the dimensions as shown in the figure above.
@@ -1268,6 +1250,7 @@ def shoulderscf(D, d, R, uts, record=False):  # as per AS1403
 
     """
     global CALCRECORD
+    from scipy import interpolate
     if (d > D):
         temp = D
         D = d
@@ -1299,7 +1282,7 @@ def shoulderscf(D, d, R, uts, record=False):  # as per AS1403
 def keyseatscf(uts, record=False):
     """
 
-        .. image:: ../../pics/keyseatscf.png
+        .. image:: ../../assets/keyseatscf.png
 
         Calculates the stress concentration factor for a sidemilled keyway with
         a H7/k6 transition fit according to AS1403 Figure 7.  The other keyways
@@ -1320,8 +1303,8 @@ def keyseatscf(uts, record=False):
     if record:
         CALCRECORD = "Keyseat SCF as per AS1403 for a sidemilled key with a H7/k6 transition fit, Shaft UTS=%.0f MPa:\n" % uts
         CALCRECORD += "$%s\\times%.0f^3-%s\\times%.0f^2+%s\\times%.0f+%.4f=%.3f$\
-\n" % (xt.engfmt(p[0], p=9, d=4, latex=True), uts, xt.engfmt(-p[1], p=6, d=4, latex=True), uts,
-            xt.engfmt(p[2], p=3, d=4, latex=True), uts, p[3], kt)
+\n" % (engfmt(p[0], p=9, d=4, latex=True), uts, engfmt(-p[1], p=6, d=4, latex=True), uts,
+            engfmt(p[2], p=3, d=4, latex=True), uts, p[3], kt)
     return kt
 
 # This is for bearing fit K8/k6 (transition fit)
@@ -1331,7 +1314,7 @@ def keyseatscf(uts, record=False):
 def bearingscf(uts, record=False):
     """
 
-        .. image:: ../../pics/bearingscf.png
+        .. image:: ../../assets/bearingscf.png
 
         Calculates the stress concentration factor for a bearing seat with
         a K8/k6 transition fit according to AS1403 Figure 5.  The other bearing
@@ -1361,7 +1344,7 @@ def bearingscf(uts, record=False):
 def shrinkscf(uts, record=False):
     """
 
-        .. image:: ../../pics/shrinkscf.png
+        .. image:: ../../assets/shrinkscf.png
 
         Calculates the stress concentration factor for a component fitted onto a
         shaft using a H7/s6 interference fit, according to Figure 6 of AS1403.
@@ -1381,8 +1364,8 @@ def shrinkscf(uts, record=False):
     if record:
         CALCRECORD = "Shrink fit SCF as per AS1403 for H7/s6 fit, Shaft UTS=%.0f MPa:\n" % uts
         CALCRECORD += "$-%s\\times%.0f^3+%s\\times%.0f^2-%s\\times%.0f+%.4f=%.3f$\
-\n" % (xt.engfmt(-p[0], p=9, d=4, latex=True), uts, xt.engfmt(p[1], p=6, d=4, latex=True), uts,
-            xt.engfmt(-p[2], p=3, d=4, latex=True), uts, p[3], scf)
+\n" % (engfmt(-p[0], p=9, d=4, latex=True), uts, engfmt(p[1], p=6, d=4, latex=True), uts,
+            engfmt(-p[2], p=3, d=4, latex=True), uts, p[3], scf)
     return scf
 
 
@@ -1535,7 +1518,7 @@ def bmdiagram(P, p=0.5, L=1.0, Q=np.zeros(2), q=0,  cc=[], draw=True, vlim=[], m
         supported beam supported by two bearings (B and C) and subject to two
         loads (P and Q) as in the following diagram:
 
-            .. image:: ../../pics/bmdiagram.png
+            .. image:: ../../assets/bmdiagram.png
 
         * ``P`` = [Py, Pz] in newtons
         * ``p`` = Position of the P application point from the left end, m
@@ -1563,9 +1546,9 @@ def bmdiagram(P, p=0.5, L=1.0, Q=np.zeros(2), q=0,  cc=[], draw=True, vlim=[], m
 
         The above will create the following two image files:
 
-            .. image:: ../../pics/examplebmdiagram_xy.png
+            .. image:: ../../assets/examplebmdiagram_xy.png
 
-            .. image:: ../../pics/examplebmdiagram_xz.png
+            .. image:: ../../assets/examplebmdiagram_xz.png
 
         and will return
 
@@ -1816,7 +1799,6 @@ def bearingpick(F, ncycles, xb=None, cr=1.0, dmin=np.array([0, 0]), record=False
     if not (type(F) == list or type(F) == np.ndarray):
         F = np.array([F, 0])
     # if xb == None:
-    #     from excel import Xcel
     #     xb = Xcel("data\\bearing.xlsx", sheetname="metric")
     # else:
     #     xb.sheet("metric")
@@ -1860,7 +1842,6 @@ def bearingpick(F, ncycles, xb=None, cr=1.0, dmin=np.array([0, 0]), record=False
 
 def bearingdims(xb, bnum, name):
     if xb == None:
-        from excel import Xcel
         xb = Xcel("bearing.xlsx", sheetname="metric")
     else:
         xb.sheet("metric")
@@ -1994,6 +1975,7 @@ def keysize(d):
 
 
 def plotidler(m, Np, Ng, Ni, beta, NA, NB, filename=""):
+    import matplotlib.pyplot as plt
     plt.clf()
     Rp = m*Np/2
     Rg = m*Ng/2
@@ -2056,7 +2038,7 @@ def scf_roundbartension(D, d=10, r=1):  # used to be scf_shaft_with_shoulder
     """
         The stress concentration factor for a stepped round bar in tension
 
-        .. image:: ../../pics/scf_roundbartension.png
+        .. image:: ../../assets/scf_roundbartension.png
 
         ``D, d, r`` are the dimensions as in the figure above in mm.
 
@@ -2122,7 +2104,7 @@ def scf_roundbarbending(D, d=10, r=1):  # used to be scf_roundbar_bending(d,D,R)
 def mohrcircle(sx, sy, txy, filename="None", figno=1, title="2d Mohr's Circle"):
     """
         For the 2d stress element:
-            .. image:: ../../pics/stresselement.png
+            .. image:: ../../assets/stresselement.png
 
         This function returns the two principal stresses and the maximum shear
         stress as (s1, s2, taumax) in MPa.
@@ -2140,7 +2122,7 @@ def mohrcircle(sx, sy, txy, filename="None", figno=1, title="2d Mohr's Circle"):
         >>> mohrcircle(10,-4,5,filename="mohrcircle.png", title="melib example")
         >>> (11.60, -5.602, 8.602)
 
-        .. image:: ../../pics/mohrcircle.png
+        .. image:: ../../assets/mohrcircle.png
 
     """
     if sx == "?":
@@ -2167,7 +2149,7 @@ filename='yourchoice.png', title='your choice')"
     dy = ymax-ymin
     textstart = amin+dx/100
     if draw_circle:
-        (fig, ax) = xt.openplot(figno, aspect=1.0)
+        (fig, ax) = openplot(figno, aspect=1.0)
         mohr = plt.Circle(((s1+s2)/2, 0), R, color='k',
                           fill=False, linewidth=2.0)
         ax = plt.gca()
@@ -2355,3 +2337,6 @@ def Et():
     Xd=Phasor(ra=[0.3,90.0])
     Et=Ef-Xd*It
     print("Et(Ef,It,Xd)=", Et)
+
+def libraryver():
+    return "4:17pm 3 June 2021"
\ No newline at end of file
